# Langchain

==> Generative AI Application --> Agentic AI Applications


Generative AI application ---> Agentic AI Applications

  LLM (===>> ). <<====>>. BRAIN
  Tools 
  Agents 

State. ---> State Management 


ReAct ---> Reason ++ Act 

Lang + Graph (Workflows)


Start

Node1 ---> LLM or Function calling

Nodel 2---> Tool Calling Functions



End




    Start 
    
    
    Edge
    
    
    Node1

Node 2          Node 2


Conditional Edges 

One Node should decide which part should go ? that is called Conditions Edges


One Node to another Node ---> The State will be change .....



# Agentic AI applications

    Start Node



